import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.util.ArrayList;

/**
 * A Ball that bounces around. Controlled using the arrow keys
 * 
 * @author Michael Berry
 * @version 17/07/08
 */
public class Ball extends Actor
{
    private double xspeed;
    private double yspeed;
    /** The force on the ball due to gravity */
    public static final double GRAVITY = 0.5;
    private BounceWorld world;
    
    /**
     * Create a new ball
     */
    public Ball()
    {
        reset();
    }
    
    /**
     * Called when the Ball is added to the world
     */
    public void addedToWorld (World world)
    {
        this.world = (BounceWorld) world;
    }
    
    /**
     * Sets the speed of the ball to 0
     */
    public void reset()
    {
        xspeed = 0;
        yspeed = 0;
    }
    
    /**
     * Steps the ball goes through continuously
     */
    public void act()
    {
        try {
            arrowKeys();
            move();
            checkBlock();
            checkWall();
            checkCoins();
            checkWin();
            checkOut();
        }
        catch(IllegalStateException ex) {}
        catch(NullPointerException ex) {}
    }
    
    /**
     * Check if we are intersecting with any coins
     */
    private void checkCoins()
    {
        Coin coin = (Coin)getOneIntersectingObject(Coin.class);
        if(coin != null)
        {
            world.addCoin();
            world.removeObject(coin);
            ((BounceWorld)getWorld()).playSound("sounds/coin.wav");
        }
        
    }
    
    /**
     * Check if we've won (hit the goal)
     */
    private void checkWin()
    {
        if(getOneIntersectingObject(Goal.class)!=null) world.won();
    }
    
    /**
     * Check if we're out the world
     */
    private void checkOut()
    {
        if(getY()>world.getHeight()-20) world.fallen();
    }
    
    /**
     * Move the ball
     */
    private void move()
    {
        setLocation((int)(getX()+xspeed), (int)(getY()+yspeed));
        yspeed += GRAVITY;
    }
    
    /**
     * Check if we've hit any block
     */
    private void checkBlock()
    {
        ArrayList<Block> blocks = (ArrayList<Block>)getObjectsInRange((int)(Math.abs(yspeed)+0.5), Block.class);
        if(blocks.size()==0) return;
        Block block = blocks.get(0);
        if(block.getY()>getY()) {
            yspeed = -block.getBounce();
        }
        else {
            yspeed = block.getBounce();
        }
        block.hit();
        ((BounceWorld)getWorld()).playSound("sounds/tock.wav");
    }
    
    /**
     * Check if we've hit the wall, bounce if we have
     */
    private void checkWall()
    {
        if(getX()<=10) {
            xspeed *= -1;
            setLocation(getX()+3, getY());
            ((BounceWorld)getWorld()).playSound("sounds/tock.wav");
        }
        else if(getX()>world.getWidth()-10) {
            xspeed *= -1;
            setLocation(getX()-3, getY());
            ((BounceWorld)getWorld()).playSound("sounds/tock.wav");
        }
        else if(getY()<=10) {
            yspeed *= -1;
            setLocation(getX(), getY()+3);
            ((BounceWorld)getWorld()).playSound("sounds/tock.wav");
        }
    }
    
    /**
     * Control the ball using the arrow keys
     */
    private void arrowKeys()
    {
        if(Greenfoot.isKeyDown("left")) xspeed -= 0.5;
        if(Greenfoot.isKeyDown("right")) xspeed += 0.5;
    }
}
