import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

/**
 * An animated coin - the starting point for this was mik's AnimatedActor class. However
 * for performance reasons and since only one animated actor is required, this has been
 * changed to a single class with all the image initialisation as static (so it's only done
 * once.) This should avoid all the long pauses between levels, especially those with lots
 * of coins.
 * 
 * @author mik
 * @author Michael Berry (mjrb4)
 * @version 03/01/09
 */
public class Coin extends Actor
{
    private static GreenfootImage[] images;
    private static int noOfImages;
    private int currentImage;
    /** The higher this is, the slower the animation */
    private final int delayTime = 4;
    private int delay = 0;
    
    /**
     * Initialise the actor - static for performance reasons.
     */
    static
    {
        String basename = "coin";
        String suffix = ".gif";
        noOfImages = 13;
        
        images = new GreenfootImage[noOfImages];
        for(int i=0; i < noOfImages; i++) {
            images[i] = new GreenfootImage(basename + (i+1) + suffix);
        }
    }
    
    /**
     * Create a new coin.
     */
    public Coin()
    {
        currentImage = Greenfoot.getRandomNumber(noOfImages-1)+1;
        setImage(images[currentImage]);
    }
    
    /**
     * Act - do whatever the AnimatedActor wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        if(delay % delayTime ==0) {
            currentImage = (currentImage + 1) % images.length;
            setImage(images[currentImage]);
        }
        delay++;
    }
}
