import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * A block that moves.
 * 
 * @author Michael Berry 
 * @version 18/07/08
 */
public class MoveBlock extends Block
{

    /** A direction - either up, down, left or right. */
    public enum Direction {UP, DOWN, LEFT, RIGHT};
    
    private int ox, oy;
    private int distance;
    private int speed;
    private Direction direction;
    private static final GreenfootImage image = new GreenfootImage("images/redBlock.png");
    
    /**
     * Create a new moving block.
     * @param distance the distance to move back and forth
     * @param speed the speed to move at
     * @param direction the direction of travel
     */
    public MoveBlock(int distance, int speed, Direction direction)
    {
        this.distance = distance;
        this.direction = direction;
        this.speed = speed;
    }
    
    /**
     * Called when the block is added to the world
     */
    public void addedToWorld(World world)
    {
        setImage(image);
        ox = getX();
        oy = getY();
    }
    
    /**
     * Move.
     */   
    public void act()
    {
        if(direction==Direction.DOWN) {
            if(getY()>=oy+distance) direction = Direction.UP;
            setLocation(getX(), getY()+speed);
        }
        else if(direction==Direction.UP) {
            if(getY()<=oy-distance) direction = Direction.DOWN;
            setLocation(getX(), getY()-speed);            
        }
        else if(direction==Direction.LEFT) {
            if(getX()<=ox-distance) direction = Direction.RIGHT;
            setLocation(getX()-speed, getY());            
        }
        else if(direction==Direction.RIGHT) {
            if(getX()>=ox+distance) direction = Direction.LEFT;
            setLocation(getX()+speed, getY());            
        }        
    }
}
