import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * A switch that turns the sound in the scenario on or off.
 * 
 * @author Michael Berry (mjrb4) 
 * @version 01/01/09
 */
public class MuteSwitch extends Actor
{
    private static final GreenfootImage muted = new GreenfootImage("images/mute.png");
    private static final GreenfootImage unmuted = new GreenfootImage("images/unmute.png");
    
    /**
     * Initially set the image to unmuted
     */
    public void addedToWorld(World world)
    {
        setImage(unmuted);
    }
    
    /**
     * If the switch is clicked on, switch between muted and unmuted.
     */
    public void act()
    {
        MouseInfo mouse = Greenfoot.getMouseInfo();
        if(mouse != null && mouse.getActor()==this && mouse.getClickCount()==1) {
            if(isMute()) setImage(unmuted);
            else setImage(muted);
            Greenfoot.playSound("sounds/switch.wav");
        }
    }
    
    /**
     * Determine whether the switch is set to muted.
     * @return true if the switch is muted, false otherwise.
     */
    public boolean isMute()
    {
        return getImage()==muted;
    }
}
